@@ -117,6 +117,7 @@ def item1_contains_item2(item1: Any, item2: Any, exact_match: bool = True) -> bo
             return False
     return item1.__contains__(item2)
 
+
 def does_list_contain_item(list_object: list, item:Any) -> bool:
     """
     Check if list contains an item
@@ -124,7 +125,15 @@ def does_list_contain_item(list_object: list, item:Any) -> bool:
     :param item: The item to check for
     :return: True or False
     """
-    return list_object.__contains__(item)
+    if len(list_object) > 0:
+        tmp = str(list_object[0])
+        if tmp.startswith("%") and tmp.endswith("%") and len(list_object) == 1:
+            return False
+        else:
+            return True
+    else:
+        return False
+
 
 def does_list_contain_any_items(list_object: list) -> bool:
     """
@@ -137,11 +146,7 @@ def does_list_contain_any_items(list_object: list) -> bool:
     if not isinstance(list_object, list):
         list_object = [list_object]
     if len(list_object) > 0:
-        tmp = str(list_object[0])
-        if tmp.startswith("%") and tmp.endswith("%") and len(list_object) == 1:
-            return False
-        else:
-            return True
+        return True
     else:
         return False
 
